from datetime import datetime, timedelta
import logging as logger
import pendulum
import time as t

from airflow import DAG
from airflow.operators.python_operator import PythonOperator

local_tz = pendulum.timezone("Europe/London")

default_args = {
    'owner': 'airflow',
    'wait_for_downstream': False,
    'start_date': datetime(2021, 2, 25, tzinfo=local_tz),
    'email_on_failure': False,
    'email_on_retry': False,
    'retries': 0,
    'retry_delay': timedelta(minutes=2)
}

dag = DAG(
    'test_dag_7'
    , catchup=False
    , max_active_runs=1
    , default_args=default_args
    , schedule_interval='6-59/10 * * * *'
    , concurrency=1)

def dummy_callable(logger, **kwargs):
    for i in range(1, 19):
        t.sleep(10)
        logger.info(f'Task is still running, time elapsed is {i*10} seconds')

##################################################
# DAG Tasks
##################################################

po_long_logger = PythonOperator(
    task_id='test_task_7'
    , python_callable=dummy_callable
    , op_kwargs={'logger': logger}
    , provide_context=True
    , dag=dag)

##################################################
# DAG Operator Flow
##################################################

po_long_logger
